---
name: "🐛 Bug report"
about: Report a bug to help improve the project
title: "[Bug] "
labels: bug
assignees: svange
---

## 🐞 Description

## 📋 Steps to reproduce

## 📈 Expected behavior

## 🖥️ Environment

- OS:
- Python version:

## Additional context
